@@ -1,6 +1,6 @@
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
-from .backend import JSONBackend
+from .backend import JSONBackend, PickleBackend
 from .exceptions import FakeItException, RecordNotFound
 from .fakeit import FakeIt
 from .models import Mode, Record
